@@ -6,6 +6,8 @@
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
+#define G_LOG_DOMAIN "mobile-settings-application"
+
 #include "mobile-settings-config.h"
 
 #include "mobile-settings-application.h"
@@ -21,6 +23,8 @@
 
 #include <phosh-plugin.h>
 
+#include <gmobile.h>
+
 #include <gdk/wayland/gdkwayland.h>
 #include <wayland-client.h>
 #include <glib/gi18n.h>
@@ -239,9 +243,10 @@ set_panel_activated (GSimpleAction *action,
   MobileSettingsApplication *self = MOBILE_SETTINGS_APPLICATION (user_data);
   MobileSettingsWindow *window;
   MsPanelSwitcher *panel_switcher;
-  gchar *panel;
+  char *panel;
+  g_autoptr (GVariant) params = NULL;
 
-  g_variant_get (parameter, "(&s)", &panel);
+  g_variant_get (parameter, "(&s@av)", &panel, &params);
 
   g_debug ("'set-panel' '%s'", panel);
 
@@ -250,11 +255,13 @@ set_panel_activated (GSimpleAction *action,
 
   if (!ms_panel_switcher_set_active_panel_name (panel_switcher, panel))
     g_warning ("Error: panel `%s` not available, launching with default options.", panel);
+
+  gtk_window_present (GTK_WINDOW (window));
 }
 
 
 MobileSettingsApplication *
-mobile_settings_application_new (gchar *application_id)
+mobile_settings_application_new (char *application_id)
 {
   return g_object_new (MOBILE_SETTINGS_TYPE_APPLICATION,
                        "application-id", application_id,
@@ -262,13 +269,33 @@ mobile_settings_application_new (gchar *application_id)
                        NULL);
 }
 
+/**
+ * mobile_settings_application_set_panel:
+ * @self: the application
+ * @panel: the panel to set
+ *
+ * Convenience wrapper to activate the given panel via the `set-panel` action.
+ */
+static void
+mobile_settings_application_set_panel (MobileSettingsApplication *self, const char *panel)
+{
+  GVariantBuilder builder;
+  g_variant_builder_init (&builder, G_VARIANT_TYPE ("av"));
+
+  g_action_group_activate_action (G_ACTION_GROUP (self),
+                                  "set-panel",
+                                  g_variant_new ("(s@av)",
+                                                 panel, g_variant_builder_end (&builder)));
+}
+
 
 static int
-mobile_settings_application_handle_local_options (GApplication *app,
-                                                  GVariantDict *options)
+mobile_settings_application_handle_local_options (GApplication *app, GVariantDict *options)
 {
+  MobileSettingsApplication *self = MOBILE_SETTINGS_APPLICATION (app);
   g_autofree GStrv panels = NULL;
   GApplicationClass *app_class = G_APPLICATION_CLASS (mobile_settings_application_parent_class);
+  g_autofree char *panel = NULL;
 
   if (g_variant_dict_contains (options, "version")) {
     print_version ();
@@ -283,13 +310,20 @@ mobile_settings_application_handle_local_options (GApplication *app,
 
     return 0;
   } else if (g_variant_dict_lookup (options, G_OPTION_REMAINING, "^a&ay", &panels)) {
-    const char *panel;
 
     g_return_val_if_fail (panels && panels[0], EXIT_FAILURE);
-    panel = panels[0];
+    panel = g_strdup (panels[0]);
+  }
 
+  if (!panel) {
+    g_autoptr (GSettings) settings = g_settings_new ("mobi.phosh.MobileSettings");
+
+    panel = g_settings_get_string (settings, "last-panel");
+  }
+
+  if (!gm_str_is_null_or_empty (panel)) {
     g_application_register (G_APPLICATION (app), NULL, NULL);
-    g_action_group_activate_action (G_ACTION_GROUP (app), "set-panel", g_variant_new ("(s)", panel));
+    mobile_settings_application_set_panel (self, panel);
   }
 
   return app_class->handle_local_options (app, options);
@@ -313,7 +347,7 @@ mobile_settings_application_activate (GApplication *app)
 
 
 static const GActionEntry actions[] = {
-  { "set-panel", set_panel_activated, "(s)", NULL, NULL, { 0 } },
+  { "set-panel", set_panel_activated, "(sav)", NULL, NULL, { 0 } },
 };
 
 
@@ -376,25 +410,24 @@ mobile_settings_application_show_about (GSimpleAction *action,
 {
   MobileSettingsApplication *self = MOBILE_SETTINGS_APPLICATION (user_data);
   GtkWindow *window;
-  AdwAboutWindow *about_window;
-  const gchar *developers[] = {"Guido Günther", "Gotam Gorabh", NULL};
-  const gchar *artists[] = {"Sam Hewitt", NULL};
+  AdwAboutDialog *about_dialog;
+  const char *developers[] = {"Guido Günther", "Gotam Gorabh", NULL};
+  const char *artists[] = {"Sam Hewitt", NULL};
 
   g_return_if_fail (MOBILE_SETTINGS_IS_APPLICATION (self));
 
-  about_window = ADW_ABOUT_WINDOW (adw_about_window_new_from_appdata ("/mobi/phosh/MobileSettings/"
+  about_dialog = ADW_ABOUT_DIALOG (adw_about_dialog_new_from_appdata ("/mobi/phosh/MobileSettings/"
                                                                       "metainfo.xml",
                                                                       MOBILE_SETTINGS_VERSION));
-  adw_about_window_set_developers (about_window, developers);
-  adw_about_window_set_artists (about_window, artists);
-  adw_about_window_set_translator_credits (about_window,
+  adw_about_dialog_set_developers (about_dialog, developers);
+  adw_about_dialog_set_artists (about_dialog, artists);
+  adw_about_dialog_set_translator_credits (about_dialog,
                /* Translators: Replace "translator-credits" with your names, one name per line */
                                            _("translator-credits"));
-  adw_about_window_set_debug_info (about_window, mobile_settings_generate_debug_info ());
+  adw_about_dialog_set_debug_info (about_dialog, mobile_settings_generate_debug_info ());
 
   window = gtk_application_get_active_window (GTK_APPLICATION (self));
-  gtk_window_set_transient_for (GTK_WINDOW (about_window), window);
-  gtk_window_present (GTK_WINDOW (about_window));
+  adw_dialog_present (ADW_DIALOG (about_dialog), GTK_WIDGET (window));
 }
 
 
