@@ -11,7 +11,6 @@
 #include "mobile-settings-application.h"
 #include "mobile-settings-debug-info.h"
 
-#define GMOBILE_USE_UNSTABLE_API
 #include <gmobile.h>
 
 /* Copied and adapted from gtk/inspector/general.c */
@@ -265,7 +264,7 @@ mobile_settings_generate_debug_info (void)
     for (int i = 0; i < G_N_ELEMENTS (schema); i++) {
       g_autoptr (GSettings) settings = g_settings_new (schema[i].schema);
       g_autoptr (GVariant) value;
-      g_autofree gchar *result;
+      g_autofree char *result;
       value = g_settings_get_value (settings, schema[i].key);
       result = g_variant_print (value, TRUE);
       g_string_append_printf (string, "- %s '%s': %s\n", schema[i].schema, schema[i].key, result);
