@@ -16,13 +16,15 @@
 #include "ms-feedback-panel.h"
 #include "ms-util.h"
 
+#include <phosh-settings-enums.h>
+
 #include <gio/gdesktopappinfo.h>
 #include <glib/gi18n.h>
 
 /* Verbatim from feedbackd */
 #define FEEDBACKD_SCHEMA_ID "org.sigxcpu.feedbackd"
 #define FEEDBACKD_KEY_PROFILE "profile"
-#define FEEDBACKD_THEME_VAR "FEEDBACK_THEME"
+#define FEEDBACKD_KEY_PREFER_FLASH "prefer-flash"
 #define APP_SCHEMA FEEDBACKD_SCHEMA_ID ".application"
 #define APP_PREFIX "/org/sigxcpu/feedbackd/application/"
 
@@ -50,10 +52,13 @@ struct _MsFeedbackPanel {
   GtkListBox                *app_listbox;
   GtkListBox                *sounds_listbox;
   GHashTable                *known_applications;
+  AdwSwitchRow              *quick_silent_switch;
 
   GSettings                 *settings;
   MsFeedbackProfile          profile;
 
+  GtkWidget                 *prefer_flash;
+
   GSoundContext             *sound_context;
   GCancellable              *sound_cancel;
 
@@ -212,7 +217,7 @@ item_feedback_profile_name (AdwEnumListItem   *item,
 static gboolean
 settings_name_to_profile (GValue *value, GVariant *variant, gpointer user_data)
 {
-  const gchar *name;
+  const char *name;
 
   name = g_variant_get_string (variant, NULL);
 
@@ -242,7 +247,7 @@ add_application_row (MsFeedbackPanel *self, MsFbdApplication *app)
   MsFeedbackRow *row;
   g_autoptr (GIcon) icon = NULL;
   g_autofree char *markup = NULL;
-  const gchar *app_name;
+  const char *app_name;
 
   app_name = g_app_info_get_name (app->app_info);
   if (STR_IS_NULL_OR_EMPTY (app_name))
@@ -353,7 +358,7 @@ static void
 update_wakeup_screen_triggers (MsFeedbackPanel *self)
 {
   gboolean wants_urgency;
-  MsPhoshNotifyScreenWakeupFlags flags, new_flags;
+  PhoshNotifyScreenWakeupFlags flags, new_flags;
 
   switch (self->notifications_urgency) {
   case MS_PHOSH_NOTIFICATION_URGENCY_LOW:
@@ -367,9 +372,9 @@ update_wakeup_screen_triggers (MsFeedbackPanel *self)
   }
 
   flags = g_settings_get_flags (self->notifications_settings, NOTIFICATIONS_WAKEUP_SCREEN_TRIGGERS_KEY);
-  new_flags = flags ^ MS_PHOSH_NOTIFY_SCREEN_WAKEUP_FLAG_URGENCY;
+  new_flags = flags ^ PHOSH_NOTIFY_SCREEN_WAKEUP_FLAG_URGENCY;
   if (wants_urgency)
-    new_flags |= MS_PHOSH_NOTIFY_SCREEN_WAKEUP_FLAG_URGENCY;
+    new_flags |= PHOSH_NOTIFY_SCREEN_WAKEUP_FLAG_URGENCY;
 
   if (flags == new_flags)
     return;
@@ -396,12 +401,12 @@ static void
 on_notifications_settings_changed (MsFeedbackPanel *self)
 {
   MsPhoshNotificationUrgency urgency;
-  MsPhoshNotifyScreenWakeupFlags flags;
+  PhoshNotifyScreenWakeupFlags flags;
 
   urgency = g_settings_get_enum (self->notifications_settings, NOTIFICATIONS_WAKEUP_SCREEN_URGENCY_KEY);
   flags = g_settings_get_flags (self->notifications_settings, NOTIFICATIONS_WAKEUP_SCREEN_TRIGGERS_KEY);
 
-  if (!(flags & MS_PHOSH_NOTIFY_SCREEN_WAKEUP_FLAG_URGENCY))
+  if (!(flags & PHOSH_NOTIFY_SCREEN_WAKEUP_FLAG_URGENCY))
     urgency = MS_PHOSH_NOTIFICATION_NONE;
 
   adw_combo_row_set_selected (self->notificationssettings_row, notifications_urgency_to_combo_pos (urgency));
@@ -470,6 +475,7 @@ static void
 ms_feedback_panel_constructed (GObject *object)
 {
   MsFeedbackPanel *self = MS_FEEDBACK_PANEL (object);
+  gboolean found;
 
   G_OBJECT_CLASS (ms_feedback_panel_parent_class)->constructed (object);
 
@@ -482,6 +488,17 @@ ms_feedback_panel_constructed (GObject *object)
                                 settings_name_to_profile,
                                 settings_profile_to_name,
                                 NULL, NULL);
+
+  g_settings_bind (self->settings, FEEDBACKD_KEY_PREFER_FLASH,
+                   self->prefer_flash, "active",
+                   G_SETTINGS_BIND_DEFAULT);
+
+  found = ms_schema_bind_property ("sm.puri.phosh",
+                                   "quick-silent",
+                                   G_OBJECT (self->quick_silent_switch),
+                                   "active",
+                                   G_SETTINGS_BIND_DEFAULT);
+  gtk_widget_set_visible (GTK_WIDGET (self->quick_silent_switch), found);
 }
 
 
@@ -524,7 +541,9 @@ ms_feedback_panel_class_init (MsFeedbackPanelClass *klass)
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/mobi/phosh/MobileSettings/ui/ms-feedback-panel.ui");
   gtk_widget_class_bind_template_child (widget_class, MsFeedbackPanel, app_listbox);
+  gtk_widget_class_bind_template_child (widget_class, MsFeedbackPanel, prefer_flash);
   gtk_widget_class_bind_template_child (widget_class, MsFeedbackPanel, sounds_listbox);
+  gtk_widget_class_bind_template_child (widget_class, MsFeedbackPanel, quick_silent_switch);
   gtk_widget_class_bind_template_child (widget_class, MsFeedbackPanel, toast_overlay);
   gtk_widget_class_bind_template_callback (widget_class, item_feedback_profile_name);
 
